function posterior = conditionalphi(uij, phi, gama, tausquared, Vsquared, ypatij, t) 

% This function returns the conditional density of phi.
% uij are the health states i valued by patient j.
% ypatij are the SG i valued by patient j.
% phi = log(alpha) of one dimension.
% gama is a vector of parameters of dimension (3x1).
% t is vector from T of dimension (1x3).

% Calculate the prior
priorsquare = (phi - t * gama)^2;
prior = exp(- priorsquare/(2 * tausquared))/sqrt(2 * pi * tausquared); % prior obtained

% Calculate the likelihood
k=length(uij);
mean = 1 - exp(phi) * (1 - uij);
lhdsquare = (ypatij - mean).^2;
kernel = exp(- lhdsquare/(2 * Vsquared))/sqrt(2 * pi * Vsquared);
lhd = prod(kernel); % likelihood obtained

% Calculate the posterior
posterior = prior * lhd; % posterior obtained
