function [us, alphas, betas, Vsquareds, sigmasquareds, tausquareds, ys]=metropolisgibbs(u0, alpha0, beta0, gama0, Vsquared0, sigmasquared0, tausquared0, A, yhs, H, NoPPHS, indiv, ypat, T, NoHSPP, HS, ndraw) 

% u0, alpha0, beta0, gama0, Vsquared0, sigmasquared0 and tausquared0 are initial parameters
% yhs is the data set sorted according to health states
% NoPPHS is the number of patients who valued the same health state
% indiv is the number of individual sorted according to health states
% ypat is the data set sorted according to patients
% NoHSPP is the number of health states valued by the same patient
% HS is the number of health states sorted according to patients


% Initializing parameters
us = [];
alphas = [];
betas = [];
Vsquareds = [];
sigmasquareds = [];
tausquareds = [];
ys = [];

% start sampling
for j = 1:ndraw
    j % Counter
    
    % u updates
    [umean, uvar]=umeanvar(alpha0, beta0, Vsquared0, sigmasquared0, A, yhs, H, NoPPHS, indiv);
    [condumean, conduvar]=condumeanvar(1, umean, uvar);
    condu=mrandn(1,condumean,conduvar);
    curru=[condu;1];
    us=[us,curru]; % Current u matrix
    
    % alpha updates
    curralpha = alphaiterate(curru, alpha0, gama0, tausquared0, Vsquared0, ypat, T, NoHSPP, HS);
    alphas=[alphas,curralpha]; % Current alpha matrix
    
    % beta updates
    [betamean, betavar]=betameanvar(curru, sigmasquared0, A, H);
    currbeta=mrandn(1,betamean,betavar);
    betas=[betas,currbeta]; % Current beta matrix
    
    % Vsquared and ys updates
    [Vsquareda, Vsquaredb, curry]=Vsquaredab(curru, curralpha, ypat, NoHSPP, HS);
    currVsquared=randinvgamma(1,Vsquareda,Vsquaredb);
    Vsquareds=[Vsquareds,currVsquared]; % Current Vsquared vector
    ys=[ys,curry]; % Current y matrix
    
    % sigmasquared updates
    [sigmasquareda, sigmasquaredb]=sigmasquaredab(curru, currbeta, A, H);
    currsigmasquared=randinvgamma(1,sigmasquareda,sigmasquaredb);
    sigmasquareds=[sigmasquareds,currsigmasquared]; % Current sigmasquared vector
    
    % tausquared updates
    [tausquareda, tausquaredb]=tausquaredab(curralpha, gama0, T);
    currtausquared=randinvgamma(1,tausquareda,tausquaredb);
    tausquareds=[tausquareds,currtausquared]; % Current tausquared vector
    
    % Updating initial values
    u0 = curru;
    alpha0 = curralpha;
    beta0 = currbeta;
    Vsquared0 = currVsquared;
    sigmasquared0 = currsigmasquared;
    tausquared0 = currtausquared;
    
end % end sampling

% Update values
us;
alphas;
betas;
Vsquareds;
sigmasquareds;
tausquareds;
ys;

% ========================================
